# methods

## user

- [x] login
- [x] create api token
- [x] logout
- [x] get session info
- [x] delete user session
- [x] change password
- [x] get user profile
- [x] set user profile
- [x] check for update

## dashboard

- [-] get stats
- [-] get top stats
- [x] delete all stats

## authoritative zone

- [x] list zones
- [-] create zone
- [x] enable zone
- [x] disable zone
- [x] delete zone
- [-] resync zone
- [x] get zone options
- [ ] set zone options
- [x] get zone permissions
- [ ] set zone permissions
- [x] sign zone
- [x] unsign zone
- [ ] get dnssec properties
- [ ] convert to nsec
- [ ] convert to nsec3
- [ ] update nsec3 parameters
- [ ] update dnskey ttl
- [ ] generate private key
- [ ] update private key
- [ ] delete private key
- [ ] publish all private keys
- [ ] rollover dnskey
- [ ] retire dnskey
- [ ] add record
- [ ] get records
- [ ] delete record
- [ ] update record

## dns cache

- [ ] list cached zones
- [ ] delete cached zone
- [ ] flush cache

## allowed zones

- [ ] list allowed zones
- [ ] allow zone
- [ ] delete allowed zone
- [ ] flush allowed zone
- [ ] import allowed zones
- [ ] export allowed zones

## blocked zones

- [ ] list blocked zones
- [ ] block zone
- [ ] delete blocked zone
- [ ] flush blocked zone
- [ ] import blocked zones
- [ ] export blocked zones

## dns apps

- [ ] list apps
- [ ] list store apps
- [ ] download and install app
- [ ] download and update app
- [ ] install app
- [ ] update app
- [ ] uninstall app
- [ ] get app config
- [ ] set app config

## dns client

- [ ] resolve query

## settings

- [ ] get dns settings
- [ ] set dns settings
- [ ] force update block lists
- [ ] temporarily disable block lists
- [ ] backup settings
- [ ] restore settings

## dhcp

- [ ] list dhcp leases
- [ ] remove dhcp lease
- [ ] convert to reserved lease
- [ ] convert to dynamic lease
- [ ] list dhcp scopes
- [ ] get dhcp scope
- [ ] set dhcp scope
- [ ] add reserved lease
- [ ] remove reserved lease
- [ ] enable dhcp scope
- [ ] disable dhcp scope
- [ ] delete dhcp scope

## administration

- [ ] list sessions
- [ ] create api token
- [ ] delete session
- [ ] list users
- [ ] create user
- [ ] get user details
- [ ] set user details
- [ ] delete user
- [ ] list groups
- [ ] create group
- [ ] get group details
- [ ] set group details
- [ ] delete group
- [ ] list permissions
- [ ] get permission details
- [ ] set permission details

## log

- [ ] list logs
- [ ] download log
- [ ] delete log
- [ ] delete all logs
- [ ] query logs
